==> foundation-2.2.0.tgz: package/lib/esm/List.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import Column from "./Column";
import Row from "./Row";
import Stack from "./Stack";
import { Text } from "./text";
var List = function (_a) {
    var items = _a.items, _b = _a.type, type = _b === void 0 ? "unordered" : _b, props = __rest(_a, ["items", "type"]);
    return (_jsx(Stack, __assign({ as: type === "unordered" ? "ul" : "ol" }, props, { children: items.map(function (item, index) { return (_jsxs(Row, __assign({ as: "li", gap: "sm" }, { children: [_jsx(Column, { children: _jsx(Text, __assign({ as: "div" }, { children: type === "unordered" ? "•" : index + 1 + "." })) }), _jsx(Column, __assign({ width: "expand" }, { children: _jsx(Text, __assign({ as: "div", lineGap: 1 / 2 }, { children: item }), index) }))] }))); }) })));
};
export default List;

==> foundation-2.3.1.tgz: package/lib/esm/List.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { forwardRef } from "react";
import Column from "./Column";
import Row from "./Row";
import Stack from "./Stack";
import { Text } from "./text";
var List = function (_a, ref) {
    var items = _a.items, _b = _a.type, type = _b === void 0 ? "unordered" : _b, props = __rest(_a, ["items", "type"]);
    return (_jsx(Stack, __assign({ ref: ref, as: type === "unordered" ? "ul" : "ol" }, props, { children: items.map(function (item, index) { return (_jsxs(Row, __assign({ as: "li", gap: "sm" }, { children: [_jsx(Column, { children: _jsx(Text, __assign({ as: "div" }, { children: type === "unordered" ? "•" : index + 1 + "." })) }), _jsx(Column, __assign({ width: "expand" }, { children: _jsx(Text, __assign({ as: "div", lineGap: 1 / 2 }, { children: item }), index) }))] }))); }) })));
};
export default forwardRef(List);
